#!/bin/sh

echo "- - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -"

SCRIPT_DIR=$(dirname "$0")
INSTALL_DIR_BASE=$(readlink -f "$SCRIPT_DIR/..")

# Setup localization
export TEXTDOMAIN=install
export TEXTDOMAINDIR=$INSTALL_DIR_BASE/share/locale
# Adjust PATH to use custom 'gettext' if there is no 'gettext' in system
export PATH=$PATH:$INSTALL_DIR_BASE/bin

which gettext || gettext() {
	echo "$1"
}

echo "TEXTDOMAINDIR<$TEXTDOMAINDIR>"

MSG_AUTH_PROMPT=$(gettext "Please enter root's password:")

X_KDESU=`which kdesu 2>/dev/null`
if [ -z "${X_KDESU}" ] ; then
    X_KDESU=`kde4-config --locate kdesu --path exe 2>/dev/null`
fi
echo "X_KDESU='${X_KDESU}'"

X_GKSU=`which gksu 2>/dev/null`
echo "X_GKSU='${X_GKSU}'"

X_GKSUDO=`which gksudo 2>/dev/null`
echo "X_GKSUDO='${X_GKSUDO}'"

X_SU=`which su 2>/dev/null`
echo "X_SU='${X_SU}'"

X_XTERM=`which xterm 2>/dev/null`
echo "X_XTERM='${X_XTERM}'"

X_GNOME_TERMINAL=`which gnome-terminal 2>/dev/null`
echo "X_GNOME_TERMINAL='${X_GNOME_TERMINAL}'"

echo "- - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -"

echo "\$#=$#"
if [ $# -lt 1 ] ; then
    echo "Usage: $0 \"cmd [args]\""
    exit -1
fi

X_CMD="$@"
echo "X_CMD='${X_CMD}'"


echo "- - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -"

if [ -n "${X_KDESU}" ] ; then

    echo "using '${X_KDESU}'"
    ${X_KDESU} "${X_CMD}"

elif [ -n "${X_GKSU}" ] ; then

    echo "using '${X_GKSU}'"
    ${X_GKSU} "${X_CMD}"

elif [ -n "${X_GKSUDO}" ] ; then

    echo "using '${X_GKSUDO}'"
    ${X_GKSUDO} "${X_CMD}"

elif [ -n "${X_SU}" -a -n "${X_XTERM}" ] ; then

    echo "using '${X_SU}' and '${X_XTERM}'"
    ${X_XTERM} -geom 60x4 -T "${MSG_AUTH_PROMPT}" -e ${X_SU} -c "${X_CMD}"

elif [ -n "${X_SU}" -a -n "${X_GNOME_TERMINAL}" ] ; then

    echo "using '${X_SU}' and '${X_GNOME_TERMINAL}'"
    ${X_GNOME_TERMINAL} --geometry 60x4 --title "${MSG_AUTH_PROMPT}" -e "${X_SU} -c ${X_CMD}"

else

    echo "ERROR: unsupported configuration -- unable to run as root"
    "${X_CMD}"

fi

echo "\$?=$?"
echo "- - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -"
